# django imports
from django.utils.translation import ugettext_lazy as _

# lfc imports
from lfc.utils.registration import register_content_type
from lfc.utils.registration import unregister_content_type

# lfc_page imports
from lfc_page.models import Page

name = "Page"
description = _(u"HTML pages for LFC")


def install():
    """Installs the blog application.
    """
    # Register objects
    register_content_type(
        Page,
        name="Page",
        sub_types=["Page"],
        templates=["Article", "Plain", "Gallery", "Overview"],
        default_template="Article")


def uninstall():
    """Uninstalls the blog application.
    """
    # Unregister content type
    unregister_content_type("Page")



# django imports
from django.db import models
from django.utils.translation import ugettext_lazy as _

# lfc imports
import lfc.utils
from lfc.models import BaseContent


class Page(BaseContent):
    """
    A Page displays HTML to the CMS user.

    **Attributes**:

    text:
        The main text of the Page.
    """
    text = models.TextField(_(u"Text"), blank=True)

    def get_searchable_text(self):
        """
        Returns the searchable text of the page. This adds the text to the
        default searchable text.
        """
        searchable_text = self.title + " " + self.description + self.text
        return lfc.utils.html2text(searchable_text)

    def edit_form(self, **kwargs):
        """
        Returns the edit form of the page.
        """
        from lfc_page.forms import PageDataForm
        return PageDataForm(**kwargs)



# django imports
from django import forms

# lfc imports
from lfc.fields.autocomplete import AutoCompleteTagInput
from lfc.fields.wysiwyg import WYSIWYGInput

# tagging imports
from tagging.forms import TagField

# lfc_page imports
from lfc_page.models import Page


class PageDataForm(forms.ModelForm):
    """Core data form for pages.
    """
    tags = TagField(widget=AutoCompleteTagInput(), required=False)

    class Meta:
        model = Page
        fields = ("title", "display_title", "slug", "description", "text", "tags")

    def __init__(self, *args, **kwargs):
        super(PageDataForm, self).__init__(*args, **kwargs)
        self.fields["text"].widget = WYSIWYGInput()
